Plugin class abstract

Implementers

Constructors

Plugin({required String name})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logError(String message, {Object? error, StackTrace? stackTrace, LogLevel level = LogLevel.error}) → void
logs an error event
logEvent(String name, {required String category, required String action, int? value, LogLevel level = LogLevel.info}) → void
logs a generic event
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited