SentryConfig class
Constructors
-
SentryConfig({required OptionsConfiguration optionsConfiguration, FutureOr<
void> appRunner()?}) -
const
Properties
-
appRunner
→ FutureOr<
void> Function()? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- optionsConfiguration → OptionsConfiguration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited